@@ -280,6 +280,7 @@ AdvancedSecurityOptionsInputTypeDef = TypedDict(
         "InternalUserDatabaseEnabled": bool,
         "MasterUserOptions": "MasterUserOptionsTypeDef",
         "SAMLOptions": "SAMLOptionsInputTypeDef",
+        "AnonymousAuthEnabled": bool,
     },
     total=False,
 )
@@ -298,6 +299,8 @@ AdvancedSecurityOptionsTypeDef = TypedDict(
         "Enabled": bool,
         "InternalUserDatabaseEnabled": bool,
         "SAMLOptions": "SAMLOptionsOutputTypeDef",
+        "AnonymousAuthDisableDate": datetime,
+        "AnonymousAuthEnabled": bool,
     },
     total=False,
 )
